@@ -12,14 +12,9 @@ The :doc:`uproot.cache.LRUArrayCache` implements the same policy, limiting the
 total number of bytes, as reported by ``nbytes``.
 """
 
-from __future__ import absolute_import
 
 import threading
-
-try:
-    from collections.abc import MutableMapping
-except ImportError:
-    from collections import MutableMapping
+from collections.abc import MutableMapping
 
 import uproot
 
@@ -73,8 +68,8 @@ class LRUCache(MutableMapping):
         if self._limit is None:
             limit = "(no limit)"
         else:
-            limit = "({0}/{1} full)".format(self._current, self._limit)
-        return "<LRUCache {0} at 0x{1:012x}>".format(limit, id(self))
+            limit = f"({self._current}/{self._limit} full)"
+        return f"<LRUCache {limit} at 0x{id(self):012x}>"
 
     @property
     def limit(self):
@@ -163,8 +158,7 @@ class LRUCache(MutableMapping):
     def __iter__(self):
         with self._lock:
             order = list(self._order)
-        for x in order:
-            yield x
+        yield from order
 
     def __len__(self):
         with self._lock:
@@ -220,14 +214,14 @@ class LRUArrayCache(LRUCache):
             limit = None
         else:
             limit = uproot._util.memory_size(limit_bytes)
-        super(LRUArrayCache, self).__init__(limit)
+        super().__init__(limit)
 
     def __repr__(self):
         if self._limit is None:
             limit = "(no limit)"
         else:
-            limit = "({0}/{1} bytes full)".format(self._current, self._limit)
-        return "<LRUArrayCache {0} at 0x{1:012x}>".format(limit, id(self))
+            limit = f"({self._current}/{self._limit} bytes full)"
+        return f"<LRUArrayCache {limit} at 0x{id(self):012x}>"
 
     @property
     def limit(self):
