@@ -252,16 +252,18 @@ class AsDtype(Numerical):
     def awkward_form(
         self,
         file,
+        context=None,
         index_format="i64",
         header=False,
         tobject_header=True,
         breadcrumbs=(),
     ):
+        context = self._make_context(
+            context, index_format, header, tobject_header, breadcrumbs
+        )
         awkward = uproot.extras.awkward()
         d, s = _dtype_shape(self._to_dtype)
-        out = uproot._util.awkward_form(
-            d, file, index_format, header, tobject_header, breadcrumbs
-        )
+        out = uproot._util.awkward_form(d, file, context)
         for size in s[::-1]:
             out = awkward.forms.RegularForm(out, size)
         return out
@@ -338,7 +340,7 @@ class AsDtype(Numerical):
         dtype, shape = _dtype_shape(self._from_dtype)
         try:
             output = data.view(dtype).reshape((-1,) + shape)
-        except ValueError:
+        except ValueError as err:
             raise ValueError(
                 """basket {} in tree/branch {} has the wrong number of bytes ({}) """
                 """for interpretation {}
@@ -349,7 +351,7 @@ in file {}""".format(
                     self,
                     branch.file.file_path,
                 )
-            )
+            ) from err
 
         self.hook_after_basket_array(
             data=data,
@@ -400,7 +402,7 @@ class AsDtypeInPlace(AsDtype):
         Specialized version of _prepare_output : re-use our target array kept in self._to_fill.
         """
         if library.name != "np":
-            raise Exception(
+            raise TypeError(
                 "AsDtypeInPlace can only be used with library 'np', not '{}'".format(
                     library.name
                 )
@@ -409,7 +411,7 @@ class AsDtypeInPlace(AsDtype):
         output = self._to_fill.view(self.to_dtype)
 
         if length > len(output):
-            raise Exception(
+            raise ValueError(
                 "Requesting to fill an array of size {} (type {}) with input of size {} (type {})".format(
                     len(output), self._to_dtype, length, self._from_dtype
                 )
@@ -540,7 +542,7 @@ class TruncatedNumerical(Numerical):
 
         try:
             raw = data.view(self.from_dtype)
-        except ValueError:
+        except ValueError as err:
             raise ValueError(
                 """basket {} in tree/branch {} has the wrong number of bytes ({}) """
                 """for interpretation {} (expecting raw array of {})
@@ -552,7 +554,7 @@ in file {}""".format(
                     repr(self._from_dtype),
                     branch.file.file_path,
                 )
-            )
+            ) from err
 
         if self.is_truncated:
             exponent = raw["exponent"].astype(numpy.int32)
@@ -636,11 +638,15 @@ class AsDouble32(TruncatedNumerical):
     def awkward_form(
         self,
         file,
+        context=None,
         index_format="i64",
         header=False,
         tobject_header=True,
         breadcrumbs=(),
     ):
+        context = self._make_context(
+            context, index_format, header, tobject_header, breadcrumbs
+        )
         awkward = uproot.extras.awkward()
         out = awkward.forms.NumpyForm(
             (),
@@ -702,11 +708,15 @@ class AsFloat16(TruncatedNumerical):
     def awkward_form(
         self,
         file,
+        context=None,
         index_format="i64",
         header=False,
         tobject_header=True,
         breadcrumbs=(),
     ):
+        context = self._make_context(
+            context, index_format, header, tobject_header, breadcrumbs
+        )
         awkward = uproot.extras.awkward()
         out = awkward.forms.NumpyForm(
             (),
