@@ -34,8 +34,8 @@ class FileResource(uproot.source.chunk.Resource):
         self._file_path = file_path
         try:
             self._file = open(self._file_path, "rb")
-        except uproot._util._FileNotFoundError:
-            raise uproot._util._file_not_found(file_path)
+        except uproot._util._FileNotFoundError as err:
+            raise uproot._util._file_not_found(file_path) from err
 
     @property
     def file(self):
